@@ -12,18 +12,11 @@ from pydantic import BaseModel, BaseSettings, validator
 from fidesctl.core.utils import echo_red, generate_request_headers
 
 
-class MissingConfig(Exception):
-    """Custom exception for when no valid configuration file is provided."""
-
-    def __init__(self) -> None:
-        message: str = "No configuration file provided!"
-        super().__init__(message)
-
-
 class FidesSettings(BaseSettings):
     """Class used as a base model for configuration subsections."""
 
     class Config:
+        extra = "forbid"
 
         # Set environment variables to take precedence over init values
         @classmethod
@@ -33,7 +26,7 @@ class FidesSettings(BaseSettings):
             env_settings: SettingsSourceCallable,
             file_secret_settings: SettingsSourceCallable,
         ) -> Tuple[SettingsSourceCallable, ...]:
-            return env_settings, init_settings
+            return env_settings, init_settings, file_secret_settings
 
 
 class UserSettings(FidesSettings):
@@ -75,41 +68,37 @@ class APISettings(FidesSettings):
 class FidesctlConfig(BaseModel):
     """Umbrella class that encapsulates all of the config subsections."""
 
-    api: APISettings
-    cli: CLISettings
-    user: UserSettings
+    api: APISettings = APISettings()
+    cli: CLISettings = CLISettings()
+    user: UserSettings = UserSettings()
 
 
 def get_config(config_path: str = "") -> FidesctlConfig:
     """
     Attempt to read config file from:
     a) passed in configuration, if it exists
-    b) env var FIDES_CONFIG_PATH
+    b) env var FIDESCTL_CONFIG_PATH
     b) local directory
     c) home directory
 
     This will fail on the first encountered bad conf file.
     """
+    default_file_name = "fidesctl.toml"
 
     possible_config_locations = [
         config_path,
         os.getenv("FIDESCTL_CONFIG_PATH", ""),
-        os.path.join(os.curdir, "fidesctl.toml"),
-        os.path.join(os.path.expanduser("~"), "fidesctl.toml"),
+        os.path.join(os.curdir, default_file_name),
+        os.path.join(os.path.expanduser("~"), default_file_name),
     ]
 
     for file_location in possible_config_locations:
         if file_location != "" and os.path.isfile(file_location):
             try:
                 settings = toml.load(file_location)
-                fides_config = FidesctlConfig(
-                    api=APISettings.parse_obj(settings.get("api", {})),
-                    cli=CLISettings.parse_obj(settings.get("cli", {})),
-                    user=UserSettings.parse_obj(settings.get("user", {})),
-                )
+                fidesctl_config = FidesctlConfig.parse_obj(settings)
+                return fidesctl_config
             except IOError:
                 echo_red(f"Error reading config file from {file_location}")
-            break
-    else:
-        raise MissingConfig
-    return fides_config
+    fidesctl_config = FidesctlConfig()
+    return fidesctl_config
